from django import forms

from .models import Category

class SearchForm(forms.Form):
    q = forms.CharField(
        label='Search', 
        max_length=100,
        required=False,
        widget=forms.TextInput(
            attrs={
                'class': 'form-control',
                'placeholder': 'Search'
                }
            ),
        )

    category = forms.ModelChoiceField(
        label="Site", 
        queryset=Category.objects.all(), 
        empty_label="All Sites", # Sets the name of the null option
        required=False,
        widget=forms.Select(
            attrs={
                'class': 'form-select',
                'placeholder': 'All Sites'
            }
        ),
    )

    sort = forms.ChoiceField(
        label="Sort by", 
        choices=[('1', 'Date'), ('2', 'Views'), ('3', 'Likes'), ('4', 'Relevance')],
        initial='1',
        required=False,
        widget=forms.Select(
            attrs={
                'class': 'form-select',
            }
        )
    )

    sort_order = forms.ChoiceField(
        label="Sort order", 
        choices=[('1', 'Descending'), ('2', 'Ascending')],
        initial='1',
        required=False,
        widget=forms.Select(
            attrs={
                'class': 'form-select',
            }
        )
    )

    mature = forms.ChoiceField(
        label="Filter by Mature", 
        choices=[('1', 'All'),('2', 'General'), ('3', 'Mature/Adult')],
        initial='1',
        required=False,
        widget=forms.RadioSelect(
            attrs={
                'class': 'form-check-input',
            }
        ),
    )

